@@ -14,7 +14,10 @@
 
 // KF
 #include <KMessageBox>
+#include <knotifications_version.h>
+#if KNOTIFICATIONS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 #include <KPassivePopup>
+#endif
 #include <KRecentDocument>
 #include <KAboutData>
 #include <KConfig>
@@ -25,8 +28,7 @@
 #include <KLocalizedString>
 #include <kwidgetsaddons_version.h>
 
-#include <knotifications_export.h>
-#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 79)
+#if KNOTIFICATIONS_VERSION < QT_VERSION_CHECK(5, 240, 0)
 #include <QDesktopWidget>
 #endif
 
@@ -595,7 +597,7 @@ int main(int argc, char *argv[])
 
 QT_WARNING_PUSH
 QT_WARNING_DISABLE_DEPRECATED
-#if KNOTIFICATIONS_BUILD_DEPRECATED_SINCE(5, 79)
+#if KNOTIFICATIONS_VERSION < QT_VERSION_CHECK(5, 240, 0)
         // ...did not work, use KPassivePopup as fallback
 
         // parse timeout time again, so it does not auto-close the fallback (timer cannot handle -1 time)
@@ -888,6 +890,7 @@ QT_WARNING_POP
 
         QFileDialog dlg;
         dlg.setOption(QFileDialog::ShowDirsOnly, true);
+        dlg.setFileMode(QFileDialog::Directory);
         dlg.setDirectoryUrl(initialDirectory(startUrl));
         dlg.selectFile(initialSelection(startUrl));
         Utils::handleXGeometry(&dlg);
@@ -915,7 +918,9 @@ QT_WARNING_POP
               : (groupStr == QLatin1String("Toolbar")) ? KIconLoader::Toolbar
               : (groupStr == QLatin1String("MainToolbar")) ? KIconLoader::MainToolbar
               : (groupStr == QLatin1String("Small")) ? KIconLoader::Small
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
               : (groupStr == QLatin1String("Panel")) ? KIconLoader::Panel
+#endif
               : (groupStr == QLatin1String("Dialog")) ? KIconLoader::Dialog
               : (groupStr == QLatin1String("User")) ? KIconLoader::User
               : /* else */ KIconLoader::NoGroup;
